pyrsistent: Persistent data structures in Python
================================================

Description
-----------

Pyrsistent is a number of persistent collections (by some referred to as
functional data structures). Persistent in the sense that they are immutable.

License
-------

MIT License


Upstream Contact
----------------

Home page: http://github.com/tobgu/pyrsistent/

Dependencies
------------

- Python
- Setuptools
- hypothesis
- memory-profiler
- psutil
- pyperform
- pytest
- Sphinx
- sphinx-rtd-theme
- tox
